@@ -5,17 +5,17 @@
 # pylint: disable=missing-docstring, invalid-name, no-member
 from __future__ import absolute_import
 
+import collections
 import copy
-import logging
 import io
 import os
 import os.path
+import pathlib
 import unittest
 
 import anyconfig.api as TT
 import anyconfig.backends
 import anyconfig.backend.json
-import anyconfig.compat
 import anyconfig.dicts
 import anyconfig.processors
 import anyconfig.schema
@@ -23,13 +23,10 @@ import anyconfig.template
 import tests.common
 
 from tests.common import (
-    CNF_0, SCM_0, CNF_1, dicts_equal, resdir, skip_test
+    CNF_0, SCM_0, CNF_1, respath
 )
 
 
-# suppress logging messages.
-TT.LOGGER.setLevel(logging.CRITICAL)
-
 CNF_XML_1 = {'config': {'@attrs': {'name': 'foo'},
                         'a': '0',
                         'b': {'@attrs': {'id': 'b0'}, '@text': 'bbb'},
@@ -44,7 +41,7 @@ CNF_XML_1 = {'config': {'@attrs': {'name': 'foo'},
 NULL_CNTNR = TT.anyconfig.dicts.convert_to({})
 
 
-class MyODict(anyconfig.compat.OrderedDict):
+class MyODict(collections.OrderedDict):
     pass
 
 
@@ -99,8 +96,10 @@ class TestBase(unittest.TestCase):
     upd = dict(a=2, b=dict(b=[1, 2, 3, 4, 5], d="D"), e=0)
 
     def assert_dicts_equal(self, dic, ref, ordered=False):
-        self.assertTrue(dicts_equal(dic, ref, ordered=ordered),
-                        "%r%s vs.%s%r" % (dic, os.linesep, os.linesep, ref))
+        self.assertEqual(
+            dic, ref,
+            "%r%s vs.%s%r" % (dic, os.linesep, os.linesep, ref)
+        )
 
 
 class Test_20_dumps_and_loads(TestBase):
@@ -157,10 +156,9 @@ class Test_20_dumps_and_loads(TestBase):
         self.assertEqual(cnf_2["b"]["b"], CNF_0["b"]["b"])
         self.assertEqual(cnf_2["b"]["c"], CNF_0["b"]["c"])
 
+    @unittest.skipIf(not anyconfig.schema.JSONSCHEMA_IS_AVAIL,
+                     "json schema lib is not available")
     def test_49_loads_w_validation_error(self):
-        if not anyconfig.schema.JSONSCHEMA_IS_AVAIL:
-            skip_test()
-
         cnf_s = """{"a": "aaa"}"""
         scm_s = TT.dumps(SCM_0, "json")
         cnf_2 = TT.loads(cnf_s, ac_parser="json", ac_schema=scm_s)
@@ -169,9 +167,8 @@ class Test_20_dumps_and_loads(TestBase):
 
 class Test_22_single_load(TestBase):
 
-    a_path = os.path.join(resdir(), "00-cnf.json")
+    a_path = respath('00-cnf.json')
     cnf = CNF_1
-    pathlib = anyconfig.compat.pathlib
 
     def test_10__single_load(self):
         res = TT.single_load(self.a_path)
@@ -191,10 +188,9 @@ class Test_22_single_load(TestBase):
         self.assert_dicts_equal(res, self.cnf)
 
     def test_30__single_load__pathlib(self):
-        if self.pathlib:
-            pobj = self.pathlib.Path(self.a_path)
-            res = TT.single_load(pobj)
-            self.assert_dicts_equal(res, self.cnf)
+        pobj = pathlib.Path(self.a_path)
+        res = TT.single_load(pobj)
+        self.assert_dicts_equal(res, self.cnf)
 
 
 class TestBaseWithIO(TestBase):
@@ -250,11 +246,11 @@ class Test_30_single_load(TestBaseWithIO):
         if not anyconfig.template.SUPPORTED:
             return
 
-        cpath = os.path.join(resdir(), "30-00-template-cnf.json")
+        cpath = respath('30-00-template-cnf.json')
         cnf = TT.single_load(cpath, ac_template=True, ac_context=self.cnf)
         self.assert_dicts_equal(cnf, self.cnf)
 
-        spath = os.path.join(resdir(), "30-00-template-cnf-ng-scm.json")
+        spath = respath('30-00-template-cnf-ng-scm.json')
 
         # Validation should fail.
         cnf2 = TT.single_load(cpath, ac_template=True, ac_context=self.cnf,
@@ -265,19 +261,18 @@ class Test_30_single_load(TestBaseWithIO):
         if not anyconfig.template.SUPPORTED:
             return
 
-        a_path = os.path.join(resdir(), "30-00-cnf.json")
-        a2_path = os.path.join(resdir(), "00-00-cnf.json")  # Not a template
+        a_path = respath('30-00-cnf.json')
+        a2_path = respath('00-00-cnf.json')  # Not a template
 
         cnf1 = TT.single_load(a_path, ac_template=True, ac_context=self.cnf)
-        self.assertTrue(dicts_equal(self.cnf, cnf1), str(cnf1))
+        self.assertEqual(self.cnf, cnf1, str(cnf1))
 
         cnf2 = TT.single_load(a2_path, ac_template=True)
         self.assertEqual(cnf2["a"], 1)
 
+    @unittest.skipIf(not anyconfig.schema.JSONSCHEMA_IS_AVAIL,
+                     "json schema lib is not available")
     def test_19_dump_and_single_load_with_validation(self):
-        if not anyconfig.schema.JSONSCHEMA_IS_AVAIL:
-            skip_test()
-
         cnf = CNF_0
         scm = SCM_0
 
@@ -292,7 +287,7 @@ class Test_30_single_load(TestBaseWithIO):
         cnf_1 = TT.single_load(cnf_path, ac_schema=scm_path)
 
         self.assertFalse(cnf_1 is None)  # Validation should succeed.
-        self.assertTrue(dicts_equal(cnf_1, cnf), cnf_1)
+        self.assertEqual(cnf_1, cnf, cnf_1)
 
         cnf_2 = cnf.copy()
         cnf_2["a"] = "aaa"  # It's type should be integer not string.
@@ -311,7 +306,7 @@ class Test_30_single_load(TestBaseWithIO):
         # items and the tests might fail.
         res = TT.single_load(self.a_path, ac_ordered=True)
         self.assert_dicts_equal(res, self.cnf, ordered=True)
-        self.assertTrue(isinstance(res, anyconfig.compat.OrderedDict))
+        self.assertTrue(isinstance(res, collections.OrderedDict))
 
     def test_22_dump_and_single_load__w_ac_dict_option(self):
         TT.dump(self.cnf, self.a_path)
@@ -346,7 +341,7 @@ class Test_32_single_load(unittest.TestCase):
             self.assertTrue(_is_file_object(inp))
             self.assertEqual(inp.mode, rmode)
             cpair = (self.cnf, cnf1)
-            self.assertTrue(dicts_equal(*cpair), "%r vs. %r" % cpair)
+            self.assertEqual(*cpair)
 
     def test_10_open_json_file(self):
         self._load_and_dump_with_opened_files("a.json")
@@ -398,7 +393,7 @@ class Test_34_single_load(TestBaseWithIO):
 class TestBaseWithIOMultiFiles(TestBaseWithIO):
 
     def setUp(self):
-        super(TestBaseWithIOMultiFiles, self).setUp()
+        super().setUp()
         self.b_path = os.path.join(self.workdir, "b.json")
         self.g_path = os.path.join(self.workdir, "*.json")
 
@@ -507,9 +502,9 @@ class Test_42_multi_load(TestBaseWithIOMultiFiles):
         ctx = self.dic.copy()
         TT.merge(ctx, self.upd, ac_merge=TT.MS_DICTS)
 
-        # a_path = os.path.join(resdir(), "30-00-template-cnf.json")
-        b_path = os.path.join(resdir(), "30-10-template-cnf.json")
-        g_path = os.path.join(resdir(), "30-*-template-cnf.json")
+        # a_path = respath('30-00-template-cnf.json')
+        b_path = respath('30-10-template-cnf.json')
+        g_path = respath('30-*-template-cnf.json')
 
         opts = dict(ac_merge=TT.MS_DICTS, ac_template=True, ac_context=ctx)
         try:
@@ -533,10 +528,10 @@ class Test_42_multi_load(TestBaseWithIOMultiFiles):
 class Test_44_multi_load(TestBase):
 
     def test_10_multi_load_w_validation_for_partial_single_config_files(self):
-        cpaths = [os.path.join(resdir(), "00-00-cnf.json"),
-                  os.path.join(resdir(), "00-01-cnf.json"),
-                  os.path.join(resdir(), "00-02-cnf.json")]
-        spath = os.path.join(resdir(), "00-scm.json")
+        cpaths = [respath('00-00-cnf.json'),
+                  respath('00-01-cnf.json'),
+                  respath('00-02-cnf.json')]
+        spath = respath('00-scm.json')
 
         cnf = TT.multi_load(cpaths, ac_schema=spath)
         ref = TT.multi_load(cpaths)
@@ -611,10 +606,8 @@ class Test_50_load_and_dump(TestBaseWithIOMultiFiles):
         self.assertEqual(cnf_2["b"]["b"], CNF_0["b"]["b"])
         self.assertEqual(cnf_2["b"]["c"], CNF_0["b"]["c"])
 
+    @unittest.skipIf('yml' not in TT.list_types(), "yaml lib is not available")
     def test_38_load_w_validation_yaml(self):
-        if "yml" not in TT.list_types():
-            skip_test()
-
         cnf_path = os.path.join(self.workdir, "cnf.yml")
         scm_path = os.path.join(self.workdir, "scm.yml")
         TT.dump(CNF_0, cnf_path)
